@@ -1,3 +1,11 @@
+# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 """ The default implementation of the 'IPlugin' interface. """
 
 # Standard library imports.
@@ -178,7 +186,7 @@ class Plugin(ExtensionProvider):
         """ Trait initializer. """
 
         id = '%s.%s' % (type(self).__module__, type(self).__name__)
-        logger.warn('plugin %s has no Id - using <%s>' % (self, id))
+        logger.warning('plugin %s has no Id - using <%s>' % (self, id))
 
         return id
 
@@ -186,7 +194,7 @@ class Plugin(ExtensionProvider):
         """ Trait initializer. """
 
         name = camel_case_to_words(type(self).__name__)
-        logger.warn('plugin %s has no name - using <%s>' % (self, name))
+        logger.warning('plugin %s has no name - using <%s>' % (self, name))
 
         return name
 
@@ -247,7 +255,7 @@ class Plugin(ExtensionProvider):
         """ Register the services offered by the plugin. """
 
         for trait_name, trait in self.traits(service=True).items():
-            logger.warn(
+            logger.warning(
                 'DEPRECATED: Do not use the "service=True" metadata anymore. '
                 'Services should now be offered using the service '
                 'offer extension point (envisage.service_offers) '
@@ -352,7 +360,7 @@ class Plugin(ExtensionProvider):
         # trait.
         #
         # fixme: This works for 'Instance' traits, but what about 'AdaptsTo'
-        # and 'AdaptedTo' traits?
+        # and 'Supports' traits?
         else:
             # Note that in traits the protocol can be an actual class or
             # interfacem or the *name* of a class or interface. This allows
