@@ -1,12 +1,11 @@
-#-----------------------------------------------------------------------------
+# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005-2007 by Enthought, Inc.
-#  All rights reserved.
-#
-#  Author: Dave Peterson <dpeterson@enthought.com>
-#
-#-----------------------------------------------------------------------------
-
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 """
 A base class for projects that can be displayed by the single_project
 plugin.
@@ -16,7 +15,8 @@ plugin.
 # Standard library imports.
 import logging
 import os
-import sys
+import re
+import unicodedata
 
 # Enthought library imports
 from traits.etsconfig.api import ETSConfig
@@ -25,7 +25,6 @@ from apptools.io.api import File
 from traits.api import Any, Bool, Dict, Directory, HasTraits, \
     Instance, Property, Str
 from traitsui.api import Group, View
-from traits.util.clean_strings import clean_filename
 
 # Local imports.
 #from envisage.ui.single_project.editor.project_editor import \
@@ -332,8 +331,9 @@ class Project(HasTraits):
 
         # Warn if the resource is not part of this project
         if not self._contains_resource(resource):
-            logger.warn('This Project [%s] does not contain resource [%s]' % \
-                (self, resource))
+            logger.warning(
+                'This Project [%s] does not contain resource [%s]',
+                self, resource)
 
         # Add or remove from our set of editors as requested
         if not remove:
@@ -718,4 +718,45 @@ class Project(HasTraits):
         self.dirty = True
 
 
+# Helper functions
+
+def clean_filename(name, replace_empty=""):
+    """
+    Make a user-supplied string safe for filename use.
+
+    Returns an ASCII-encodable string based on the input string that's safe for
+    use as a component of a filename or URL. The returned value is a string
+    containing only lowercase ASCII letters, digits, and the characters '-' and
+    '_'.
+    This does not give a faithful representation of the original string:
+    different input strings can result in the same output string.
+
+    Parameters
+    ----------
+    name : str
+        The string to be made safe.
+    replace_empty : str, optional
+        The return value to be used in the event that the sanitised
+        string ends up being empty. No validation is done on this
+        input - it's up to the user to ensure that the default is
+        itself safe. The default is to return the empty string.
+
+    Returns
+    -------
+    safe_string : str
+        A filename-safe version of string.
+    """
+    # Code is based on Django's slugify utility.
+    # https://docs.djangoproject.com/en/1.9/_modules/django/utils/text/#slugify
+    name = (
+        unicodedata.normalize('NFKD', name)
+        .encode('ascii', 'ignore')
+        .decode('ascii')
+    )
+    name = re.sub(r'[^\w\s-]', '', name).strip().lower()
+    safe_name = re.sub(r'[-\s]+', '-', name)
+    if safe_name == "":
+        return replace_empty
+    return safe_name
+
 #### EOF #####################################################################
